@@ -1,31 +1,25 @@
 import asyncio
-import sys
-
+import warnings
 from collections import deque
-from asyncio import Task, Future  # noqa
-from typing import Any, List, Tuple, Optional, Callable  # noqa
-
-try:
-    from typing import Deque
-except ImportError:
-    Deque = deque  # type: ignore
-
+from typing import Any, Deque, List, Optional, Tuple
 
 Loop = asyncio.AbstractEventLoop
 OptLoop = Optional[Loop]
 
+# silence LGTM service alerts
+Future = asyncio.Future
+Task = asyncio.Task
 
-__version__ = '0.6.0'
-__all__ = ['RWLock']
-
-PY_35 = sys.version_info >= (3, 5, 3)
+__version__ = '1.0.0'
+__all__ = ('RWLock',)
 
 
-def current_task(loop: OptLoop = None) -> 'Task[Any]':
-    _loop = loop or asyncio.get_event_loop()  # type: Loop
+def _current_task(loop: OptLoop = None) -> 'Task[Any]':
+    _loop: Loop = loop or asyncio.get_event_loop()
     if hasattr(asyncio, 'current_task'):
         t = asyncio.current_task(loop=_loop)
     else:
+        # remove once python 3.6 deprecated
         t = asyncio.Task.current_task(loop=_loop)
     if t is None:
         raise RuntimeError('Loop is not running')
@@ -40,15 +34,15 @@ class _RWLockCore:
     _RL = 1
     _WL = 2
 
-    def __init__(self, fast: bool, loop: OptLoop):
+    def __init__(self, fast: bool, loop: Loop):
         self._do_yield = not fast
-        self._loop = loop or asyncio.get_event_loop()  # type: Loop
-        self._read_waiters = deque()  # type: Deque[Future[None]]
-        self._write_waiters = deque()  # type: Deque[Future[None]]
-        self._r_state = 0  # type: int
-        self._w_state = 0  # type: int
+        self._loop: Loop = loop
+        self._read_waiters: Deque[Future[None]] = deque()
+        self._write_waiters: Deque[Future[None]] = deque()
+        self._r_state: int = 0
+        self._w_state: int = 0
         # tasks will be few, so a list is not inefficient
-        self._owning = []  # type: List[Tuple[Task[Any], int]]
+        self._owning: List[Tuple[Task[Any], int]] = []
 
     @property
     def read_locked(self) -> bool:
@@ -58,23 +52,33 @@ class _RWLockCore:
     def write_locked(self) -> bool:
         return self._w_state > 0
 
+    async def _yield_after_acquire(self, lock_type: int) -> None:
+        if self._do_yield:
+            try:
+                await asyncio.sleep(0.0, loop=self._loop)
+            except asyncio.CancelledError:
+                self._release(lock_type)
+                self._wake_up()
+                raise
+
     # Acquire the lock in read mode.
     async def acquire_read(self) -> bool:
-        me = current_task(loop=self._loop)
+        me = _current_task(loop=self._loop)
 
         if (me, self._RL) in self._owning or (me, self._WL) in self._owning:
             self._r_state += 1
             self._owning.append((me, self._RL))
-            if self._do_yield:
-                await asyncio.sleep(0.0, loop=self._loop)
+            await self._yield_after_acquire(self._RL)
             return True
 
-        if (not self._write_waiters and
-                self._r_state >= 0 and self._w_state == 0):
+        if (
+            not self._write_waiters
+            and self._r_state >= 0
+            and self._w_state == 0
+        ):
             self._r_state += 1
             self._owning.append((me, self._RL))
-            if self._do_yield:
-                await asyncio.sleep(0.0, loop=self._loop)
+            await self._yield_after_acquire(self._RL)
             return True
 
         fut = self._loop.create_future()
@@ -95,13 +99,12 @@ class _RWLockCore:
     # Acquire the lock in write mode.  A 'waiting' count is maintained,
     # ensuring that 'readers' will yield to writers.
     async def acquire_write(self) -> bool:
-        me = current_task(loop=self._loop)
+        me = _current_task(loop=self._loop)
 
         if (me, self._WL) in self._owning:
             self._w_state += 1
             self._owning.append((me, self._WL))
-            if self._do_yield:
-                await asyncio.sleep(0.0, loop=self._loop)
+            await self._yield_after_acquire(self._WL)
             return True
         elif (me, self._RL) in self._owning:
             if self._r_state > 0:
@@ -110,8 +113,7 @@ class _RWLockCore:
         if self._r_state == 0 and self._w_state == 0:
             self._w_state += 1
             self._owning.append((me, self._WL))
-            if self._do_yield:
-                await asyncio.sleep(0.0, loop=self._loop)
+            await self._yield_after_acquire(self._WL)
             return True
 
         fut = self._loop.create_future()
@@ -137,7 +139,7 @@ class _RWLockCore:
 
     def _release(self, lock_type: int) -> None:
         # assert lock_type in (self._RL, self._WL)
-        me = current_task(loop=self._loop)
+        me = _current_task(loop=self._loop)
         try:
             self._owning.remove((me, lock_type))
         except ValueError:
@@ -174,10 +176,10 @@ class _RWLockCore:
 
 
 class _ContextManagerMixin:
-
     def __enter__(self) -> None:
         raise RuntimeError(
-            '"await" should be used as context manager expression')
+            '"await" should be used as context manager expression'
+        )
 
     def __exit__(self, *args: Any) -> None:
         # This must exist because __enter__ exists, even though that
@@ -202,7 +204,6 @@ class _ContextManagerMixin:
 
 # Lock objects to access the _RWLockCore in reader or writer mode
 class _ReaderLock(_ContextManagerMixin):
-
     def __init__(self, lock: _RWLockCore) -> None:
         self._lock = lock
 
@@ -222,7 +223,6 @@ class _ReaderLock(_ContextManagerMixin):
 
 
 class _WriterLock(_ContextManagerMixin):
-
     def __init__(self, lock: _RWLockCore):
         self._lock = lock
 
@@ -251,7 +251,25 @@ class RWLock:
     core = _RWLockCore
 
     def __init__(self, *, fast: bool = False, loop: OptLoop = None) -> None:
-        self._loop = loop or asyncio.get_event_loop()  # type: Loop
+        if loop is None:
+            loop = asyncio.get_event_loop()
+        else:
+            warnings.warn(
+                'Passing "loop" argument '
+                'is deprecated since aiorwlock 1.0 and scheduled for removal '
+                'in aiorwlock 2.0',
+                DeprecationWarning,
+                stacklevel=2,
+            )
+        if not loop.is_running():
+            warnings.warn(
+                'Instantiation of RWLock outside of async function context '
+                'is deprecated since aiorwlock 1.0 and scheduled for removal '
+                'in aiorwlock 2.0',
+                DeprecationWarning,
+                stacklevel=2,
+            )
+        self._loop: Loop = loop
         core = self.core(fast, self._loop)
         self._reader_lock = _ReaderLock(core)
         self._writer_lock = _WriterLock(core)
